#include "melody.hpp"

Melody::Melody(int* mode, int* counter, int* note) :
	     Icon(-1, -1, -1, -1)
{
	// save references to state variables
	recorder_mode = mode;
	event_counter = counter;
	current_note = note;

	// set the tape counter to the beginning
	*event_counter = 0;

	// create the array for storing the melody
	event = new int [MAX_RECORDED_EVENTS];

	// clear out any garbage in the recorder
	for (int i = 0; i < MAX_RECORDED_EVENTS; i++)
	  event [i] = 0;
}

void Melody::Update()
{
	int frequency;
	static int last_frequency;

	switch (*recorder_mode) {
	case STOP:
	  if (last_frequency == 0) return;
	  EventsHandler->SoundOff();
	  last_frequency = 0;
	  return;
	case REWIND:
	  EventsHandler->SoundOff();
	  if (*event_counter >= 10)
	    *event_counter -= 10;
	  else if (*event_counter >= 1)
	    *event_counter -= 1;
	  return;
	case FAST_FORWARD:
	  EventsHandler->SoundOff();
	  if (*event_counter < MAX_RECORDED_EVENTS - 10)
	    *event_counter += 10;
	  else if (*event_counter < MAX_RECORDED_EVENTS - 1)
	    *event_counter += 1;
	  return;
	case RECORD:
	  if (*event_counter <0) return;
	  if (*event_counter >= MAX_RECORDED_EVENTS) return;
	  event [*event_counter] = *current_note;
	  (*event_counter)++;
	  return;
	case PLAY:
	  if (*event_counter < 0) *event_counter = 0;
	  if (*event_counter > MAX_RECORDED_EVENTS)
	    *event_counter = 0;

	  // make a short sound
	  frequency = event [*event_counter];
	  (*event_counter)++;
	  if (frequency == last_frequency) return;
	  last_frequency = frequency;
	  if (frequency)
	    EventsHandler->SoundOn(frequency);
	  else
	    EventsHandler->SoundOff();
	    return;
	}
}

Melody::~Melody()
{
	delete event;
}


